#ifndef SETTINGSDLG_H
#define SETTINGSDLG_H

#include <QDialog>
#include <QComboBox>
#include "colorButton.h"

class SettingsDialog : public QDialog
{
Q_OBJECT

public:
    SettingsDialog(QWidget *parent = 0);
    ~SettingsDialog();

private:
    ColorButton *names, *days, *weekends, *weeks, *cday, *cdayback, *widgetback;
    QSlider *transparence;
    QComboBox *lang;

private slots:
    void saveSettings();
};

#endif // SETTINGSDLG_H
